@@ -90,6 +90,23 @@ setClass(
     )
 )
 
+setClass(
+    "ComboGroups",
+    slots = c(
+        ptr           = "externalptr",
+        startOver     = "function",
+        nextIter      = "function",
+        nextNIter     = "function",
+        nextRemaining = "function",
+        currIter      = "function",
+        randomAccess  = "function",
+        sourceVector  = "function",
+        front         = "function",
+        back          = "function",
+        summary       = "function"
+    )
+)
+
 setMethod(
     "initialize",
     "Combo",
@@ -158,6 +175,20 @@ setMethod(
     }
 )
 
+setMethod(
+    "initialize",
+    "ComboGroups",
+    function(.Object, init, Parallel) {
+        .Object@ptr <- .Call(`_RcppAlgos_CombClassNew`, init$RVals, init$bVec,
+                             init$FreqsInfo, Parallel, NULL, NULL, NULL,
+                             NULL, NULL, NULL, NULL, NULL, NULL, 4)
+        eval(str2expression(text = ALGOS_METHODS[c(
+            "startOver", "nextIter", "nextNIter", "nextRemaining",
+            "currIter", "randomAccess", "sourceVector", "front",
+            "back", "summary", "object")]))
+    }
+)
+
 "[[.Combo" <- function(x, ...) {
     x@randomAccess(...)
 }
@@ -174,6 +205,10 @@ setMethod(
     x@randomAccess(...)
 }
 
+"[[.ComboGroups" <- function(x, ...) {
+    x@randomAccess(...)
+}
+
 ## The '$' accessor is for backwards compatibility only. Moving forward, one
 ## should prefer using the '@' accessor to avoid calling the C function
 ## 'duplicate'. For more information see:
@@ -197,3 +232,7 @@ setMethod("$", "Constraints", function(x, name) {
 setMethod("$", "Partitions", function(x, name) {
     function(...) slot(x, name)(...)
 })
+
+setMethod("$", "ComboGroups", function(x, name) {
+    function(...) slot(x, name)(...)
+})
