@@ -1,11 +1,8 @@
-#ifndef PERMUTE_HELPER_H
-#define PERMUTE_HELPER_H
+#pragma once
 
 #include "Permutations/NextPermutation.h"
 #include "Permutations/PermuteCount.h"
-#include "Cpp14MakeUnique.h"
+#include <memory>
 #include <vector>
 
 #include "cpp11/R.hpp"
-
-#endif
