@@ -1,5 +1,4 @@
-#ifndef SAMPLE_PARTITIONS_H
-#define SAMPLE_PARTITIONS_H
+#pragma once
 
 #include "cpp11/R.hpp"
 #include "Partitions/NthPartition.h"
@@ -7,9 +6,8 @@
 template <typename T>
 void ThreadSafeSample(T* mat, SEXP res, const std::vector<T> &v,
                       const std::vector<double> &mySample,
-                      mpz_t *const myBigSamp, const std::vector<int> &myReps,
+                      const std::vector<mpz_class> &myBigSamp,
+                      const std::vector<int> &myReps,
                       nthPartsPtr nthPartFun, int m, int sampSize,
                       int nThreads, bool Parallel, bool IsNamed,
                       int tar, int strtLen, int cap, bool IsGmp);
-
-#endif
